@@ -213,7 +213,8 @@ enum marpaESLIF_bootstrap_terminal_type {
   MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE_QUOTED_STRING,
   MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE__EOF,
   MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE__EOL,
-  MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE__SOL
+  MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE__SOL,
+  MARPAESLIF_BOOTSTRAP_TERMINAL_TYPE__EMPTY
 };
 
 struct marpaESLIF_bootstrap_terminal {
